@@ -9,6 +9,8 @@ Copyright (C) 2010 Nick Leppänen Larsson <frals@frals.se>
 """
 import os
 
+import osso
+
 try:
 	import gnome.gconf as gconf
 except:
@@ -20,13 +22,23 @@ CONNMODE_FORCESWITCH = 3
 
 class fMMS_config:
 
-
 	def __init__(self):
 		self._fmmsdir = "/apps/fmms/"
 		self.client = gconf.client_get_default()
 		self.client.add_dir(self._fmmsdir, gconf.CLIENT_PRELOAD_NONE)
-		if self.get_apn() == None:
-			self.set_apn("bogus")
+		apn = self.get_apn()
+		if apn == None:
+			apn = self.create_new_apn()
+			self.set_apn(apn)
+		# if its not our APN we copy settings to ours
+		if apn != "z_fMMS-APN":
+			settings = self.get_apn_settings()
+			advsettings = self.get_advanced_apn_settings()
+			apn = self.create_new_apn()
+			self.set_apn(apn)
+			self.set_apn_settings(settings)
+			self.set_advanced_apn_settings(advsettings)
+			self.set_mmsc(self.get_old_mmsc())
 		if self.get_pushdir() == None:
 			self.set_pushdir("/home/user/.fmms/push/")
 		if self.get_mmsdir() == None:
@@ -36,15 +48,15 @@ class fMMS_config:
 		if self.get_imgdir() == None:
 			self.set_imgdir("/home/user/.fmms/temp/")
 		if self.get_mmsc() == None:
-			self.set_mmsc("http://")
+			self.set_mmsc("")
 		if self.get_phonenumber() == None:
 			self.set_phonenumber("0")
 		if self.get_img_resize_width() == None:
-			self.set_img_resize_width(320)
+			self.set_img_resize_width(240)
 		if self.get_version() == None:
 			self.set_version("Unknown")
 		if self.get_connmode() == None:
-			self.set_connmode(2)
+			self.set_connmode(CONNMODE_ICDSWITCH)
 		if self.get_db_path() == None:
 			self.set_db_path("/home/user/.fmms/mms.db")
 		if not self.get_useragent():
@@ -62,21 +74,21 @@ class fMMS_config:
 		if not os.path.isdir(self.get_imgdir()):
 			os.makedirs(self.get_imgdir())
 		
-	def read_config(self):
-		pass
-		
-	def set_experimental(self, val):
-		if (val == True):
-			val = 1
-		else:
-			val = 0
-		self.client.set_int(self._fmmsdir + "exp", int(val))
-	
-	def get_experimental(self):
-		return self.client.get_int(self._fmmsdir + "exp")
+		if self.get_firstlaunch() == 0:
+			self.set_firstlaunch(1)
+			self.set_img_resize_width(240)
+			self.set_connmode(CONNMODE_ICDSWITCH)
+
+	def get_old_mmsc(self):
+		return self.client.get_string(self._fmmsdir + 'mmsc')
 	
 	def set_connmode(self, val):
+		apn = self.get_apn()
 		self.client.set_int(self._fmmsdir + "connmode", int(val))
+		if val == CONNMODE_UGLYHACK:
+			self.mask_apn_from_icd(apn)
+		else:
+			self.unmask_apn_from_icd(apn)
 		
 	def get_connmode(self):
 		return self.client.get_int(self._fmmsdir + "connmode")
@@ -157,14 +169,20 @@ class fMMS_config:
 		return self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/name')
 	
 	def get_apn(self):
-		return self.client.get_string(self._fmmsdir + "apn")
-		
+		apn = self.client.get_string(self._fmmsdir + "apn")
+		return apn
+
 	def set_mmsc(self, mmsc):
-		self.client.set_string(self._fmmsdir + "mmsc", mmsc)
+		apn = self.get_apn()
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/mmsc', mmsc)
 	
 	def get_mmsc(self):
-		return self.client.get_string(self._fmmsdir + "mmsc")
-		
+		apn = self.get_apn()
+		mmsc = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/mmsc')
+		if not mmsc:
+			mmsc = ""
+		return mmsc
+
 	def get_proxy_from_apn(self):
 		apn = self.get_apn()
 		proxy = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http')
@@ -235,8 +253,68 @@ class fMMS_config:
 						return apnid		
 		
 		return None
+	
+	def set_apn_settings(self, settings):
+		apn = self.get_apn()
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_accesspointname', settings['apn'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_username', settings['user'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/gprs_password', settings['pass'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http', settings['proxy'])
+		self.client.set_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port', int(settings['proxyport']))
+		self.set_mmsc(settings['mmsc'])
+		
+	def get_apn_settings(self):
+		apn = self.get_apn()
+		settings = {}
+		settings['apn'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_accesspointname')
+		settings['user'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_username')
+		settings['pass'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/gprs_password')
+		settings['proxy'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/proxy_http')
+		settings['proxyport'] = self.client.get_int('/system/osso/connectivity/IAP/' + apn + '/proxy_http_port')
+		settings['mmsc'] = self.get_mmsc()
+		
+		return settings
+		
+	def set_advanced_apn_settings(self, settings):
+		apn = self.get_apn()
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns1', settings['pdns'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns2', settings['sdns'])
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_address', settings['ip'])
+	
+	def get_advanced_apn_settings(self):
+		apn = self.get_apn()
+		settings = {}
+		settings['pdns'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns1')
+		settings['sdns'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_dns2')
+		settings['ip'] = self.client.get_string('/system/osso/connectivity/IAP/' + apn + '/ipv4_address')
+		return settings
+	
+	def create_new_apn(self):
+		""" Create a new APN for MMS usage. """
+		# Name it z_fMMS as auto-connect *might* 
+		# search gconf keys in alphabetical order...
+		apn = "z_fMMS-APN"
+		self.client.add_dir('/system/osso/connectivity/IAP/' + apn, gconf.CLIENT_PRELOAD_NONE)
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/type", "GPRS")
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/name", "MMS")
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/ipv4_type", "AUTO")
+		self.client.set_int('/system/osso/connectivity/IAP/' + apn + "/user_added", 2)
+		self.unmask_apn_from_icd(apn)
+		return apn
+		
+	def get_sim_imsi(self):
+		osso_c = osso.Context('fMMSconfig', '1.0', False)
+		rpc = osso.Rpc(osso_c)
+		imsi = rpc.rpc_run('com.nokia.phone.SIM', '/com/nokia/phone/SIM', 'Phone.Sim', 'get_imsi', (), True, True)
+		return imsi
+		
+	def mask_apn_from_icd(self, apn):
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/sim_imsi", "masked")
+		
+	def unmask_apn_from_icd(self, apn):
+		simimsi = self.get_sim_imsi()
+		self.client.set_string('/system/osso/connectivity/IAP/' + apn + "/sim_imsi", simimsi)
 		
 		
 if __name__ == '__main__':
-	config = fMMS_config()
-	config.set_connmode(1)
\ No newline at end of file
+	config = fMMS_config()
\ No newline at end of file
