@@ -161,7 +161,6 @@ class fMMS_ConfigDialog():
 		""" Checks if we should save the Configuration options. """
 		if action == gtk.RESPONSE_APPLY:
 			self.config.set_phonenumber(self.number.get_text())
-			log.info("Set phonenumber to %s" % self.number.get_text())
 			self.config.set_img_resize_width(self.imgwidth.get_text())
 			log.info("Set image width to %s" % self.imgwidth.get_text())
 			self.config.set_connmode(self.connmode_option())
@@ -199,8 +198,9 @@ class APNConfigDialog():
 		
 		if current['apn'] == "" or current['mmsc'] == "":
 			current = self.cont.get_apn_settings_automatically()
-			self.config.set_apn_settings(current)
-			log.info("Set APN settings: %s" % current)
+			if current:
+				self.config.set_apn_settings(current)
+				log.info("Set APN settings: %s" % current)
 		
 		for labelname in inputs:
 			(labelname, var) = labelname
